<?php

namespace Drupal\fakturoid_api\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Returns responses for Fakturoid API routes.
 */
class FakturoidApiController extends ControllerBase {

  /**
   * The node storage.
   *
   * @var \Drupal\node\NodeStorageInterface
   */
  protected $nodeStorage;

  /**
   * The logger service.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * FakturoidApiController constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   * @param \Drupal\Core\Logger\LoggerChannelInterface $logger
   *   The logger service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, LoggerChannelInterface $logger) {
    $this->nodeStorage = $entityTypeManager->getStorage('node');
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('logger.channel.subscription_service')
    );
  }

  /**
   * Handles the webhook request.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The incoming request object.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The response to the webhook request.
   */
  public function handleWebhook(Request $request) {
    // Implement your webhook handling logic here.
    // Access the request data using $request->getContent() or other methods.
    // Example: Log the webhook payload.
    $payload = json_decode($request->getContent());
    $this->logger->notice($request);

    if ($payload) {
      // Replace with the desired node ID.
      $nid = $payload->invoice_custom_id;
      $node = $this->nodeStorage->load($nid);
      // $response = [
      // 'status' => 'success',
      // 'message' => 'OK',
      // ];
    }
    else {
      // $response = [
      // 'status' => 'failed',
      // 'message' => 'No content',
      // ];
      return new Response('No content', 204);
    }
    if (isset($node)) {
      // Set the field value to true.
      $node->set('field_zaplaceno', TRUE);

      // Save the node.
      $node->save();
    }
    // Return a response.
    return new Response('OK', 200);
  }

}
